time_uuid
=======

time_uuid is a lightweight Python library for sensibly dealing with UUIDv1 (or TimeUUIDs as we like to sometimes call them). It allows you to create UUIDv1s in a variety of different ways. Take a look at `the docs <http://packages.python.org/time-uuid>`_ for the interface.

Who/What/When/Where
-------------------

Author: Samuel Sutch (`@ssutch <http://twitter.com/ssutch>`_)

PyPi: `http://pypi.python.org/pypi/time-uuid/ <http://pypi.python.org/pypi/time-uuid/>`_

Docs: `http://packages.python.org/time-uuid/ <http://packages.python.org/time-uuid/>`_

License: BSD

I am definitely open to contributions. Please feel free to submit your lock implementation.